Class: User
- Inherits:
-
ActiveRecord::Base
- Object
- ActiveRecord::Base
- User
- Includes:
- DmCore::Concerns::User
- Defined in:
- app/models/user.rb
Overview
users, user_profiles, and user_site_profiles...
User: There is one User per person/email address. Email address is the primary key. A User is created for a specific account. However, that user can login to any of the hosted sites on this system, with the same user/pass. In this way we can have a set of related sites, with single sign-on
UserProfile: Only one per User, this contains all the profile information - name, address, public/private avatars. This information is used across all sites.